from .core import route, use, run_server, protect, Boask
from .templates.html import html_templates
from .error import error_page, error_path
from .auth.login import login
from .auth.register import register
from .middleware.logging import logging_middleware
from .middleware.cors import cors
from .middleware.rate_limit import rate_limit
from .middleware.auth import auth_middleware
from .auth.ban import Ban
from werkzeug.wrappers import Request, Response
from werkzeug.routing import Map, Rule
from werkzeug.exceptions import HTTPException, NotFound
from werkzeug.serving import run_simple
from .version import __version__
import jwt

ban_user = Ban.ban_user 

__version__ = version.__version__

__all__ = [
    "route",
    "use",
    "protect",
    "run_server",
    "html_templates",
    "error_page",
    "error_path",
    "login",
    "register",
    "logging_middleware",
    "cors",
    "rate_limit",
    "auth_middleware",
    "Boask",
    "Request",
    "Response",
    "Map",
    "Rule",
    "HTTPException",
    "NotFound",
    "run_simple",
    "ban_user",
    "jwt"
]
